Class to contain input data and parameters for vsn functions
class.vsnInput.RdClass to contain input data and parameters for vsn functions
Slots
x:A numeric matrix with the input data.
reference:An object of
vsn, typically this would have been obtained from a previous fit to a set of reference arrays (data).strata:A factor of length 0 or n. If its length is n, then its levels correspond to different normalization strata (see
vsn2).ordered:Logical scalar; are the rows reordered so that the strata are contiguous.
lts.quantile:Numeric scalar, see
vsn2.subsample:Integer scalar, see
vsn2.verbose:Logical scalar, see
vsn2.calibCharacter of length 1, see manual page of
vsn2.pstart:A 3D array of size (number of strata) x (number of columns of the data matrix) x 2. It contains the start parameters.
optimpar:List with parameters for the numerical optimiser
L-BFGS-B; see the manual page ofvsn2.
Methods
[Subset
dimGet dimensions of data matrix.
nrowGet number of rows of data matrix.
ncolGet number of columns of data matrix.
showPrint a summary of the object