Intensity data for one cDNA slide with two adjacent tissue samples from a nephrectomy (kidney)
kidney.RdIntensity data for one cDNA slide with two adjacent tissue samples from a nephrectomy (kidney)
Usage
data(kidney)Format
kidney is an
ExpressionSet
containing the data from one cDNA
chip. The 8704x2 matrix exprs(kidney) contains the
spot intensities for the red (635 nm) and green color channels
(532 nm) respectively. For each spot, a background estimate from a
surrounding region was subtracted.
Details
The chip was produced in 2001 by Holger Sueltmann at the Division of Molecular Genome Analysis at the German Cancer Research Center in Heidelberg.