The transformation that is applied to the scaling parameter of the vsn model
scalingFactorTransformation.RdThe transformation that is applied to the scaling parameter of the vsn model
Value
A real vector of same length as b, with transformation f
applied (see
vignette Likelihood Calculations for vsn).
Examples
b = seq(-3, 2, length=20)
fb = scalingFactorTransformation(b)
if(interactive())
plot(b, fb, type="b", pch=16)