Apply the vsn transformation to data
vsn2trsf.RdApply the vsn transformation to data.
Usage
# S4 method for class 'vsn'
predict(object, newdata, strata=object@strata, log2scale=TRUE, useDataInFit=FALSE)Arguments
- object
An object of class
vsnthat contains transformation parameters and strata information, typically this is the result of a previous call tovsn2.- newdata
Object of class
ExpressionSet,NChannelSet,AffyBatch(from theaffypackage),RGList(from thelimmapackage),matrixornumeric, with the data to which the fit is to be applied to.- strata
Optional, a
factororintegerthat aligns with the rows ofnewdata; see thestrataargument ofvsn2.- log2scale
If
TRUE, the data are returned on the glog scale to base 2, and an overall offset c is added (see Value section of thevsn2manual page). IfFALSE, the data are returned on the glog scale to base e, and no offset is added.- useDataInFit
If
TRUE, then no transformation is attempted and the data stored inobjectis transferred appropriately into resulting object, which otherwise preserves the class and metadata ofnewdata. This option exists to increase performance in constructs likeand is used, for example, in the
justvsnfunction.
Value
An object typically of the same class as newdata. There are two
exceptions: if newdata is an
RGList, the return value is an
NChannelSet, and
if newdata is numeric, the return value is a matrix with 1
column.