Class to contain result of a vsn fit
class.vsn.RdClass to contain result of a vsn fit
Slots
coefficients:A 3D array of size (number of strata) x (number of columns of the data matrix) x 2. It contains the fitted normalization parameters (see vignette).
strata:A factor of length 0 or n. If its length is n, then its levels correspond to different normalization strata (see vignette).
mu:A numeric vector of length n with the fitted parameters \(\hat{\mu}_k\), for \(k=1,...,n\).
sigsq:A numeric scalar, \(\hat{\sigma}^2\).
hx:A numeric matrix with 0 or n rows. If the number of rows is n, then
hxcontains the transformed data matrix.lbfgsb:An integer scalar containing the return code from the L-BFGS-B optimizer.
hoffset:Numeric scalar, the overall offset \(c\)- see manual page of
vsn2.calib:Character of length 1, see manual page of
vsn2.
Methods
[Subset
dimGet dimensions of data matrix.
nrowGet number of rows of data matrix.
ncolGet number of columns of data matrix.
showPrint a summary of the object
exprsAccessor to slot
hx.coef,coefficientsAccessors to slot
coefficients.